@@ -21,7 +21,13 @@ pub use self::cluster::{
     Cluster, ClusterLocationAws, ClusterLocationAzure, ClusterLocations, ClusterName, ClusterToken,
     CreateClusterDto, Provider,
 };
-pub use self::error::{Error, Permission, StatehubError};
+pub use self::error::CLUSTER_IS_STATE_OWNER;
+pub use self::error::CLUSTER_NOT_FOUND;
+pub use self::error::NOT_AUTHORIZED;
+pub use self::error::STATE_ALREADY_EXISTS;
+pub use self::error::UNAUTHENTICATED;
+pub use self::error::VOLUME_NOT_FOUND;
+pub use self::error::{Error, Permission};
 pub use self::events::{Report, Reporter};
 pub use self::helm::Helm;
 pub use self::login::Login;
